==> keycloak-25.0.6.tar.gz: keycloak-25.0.6/model/infinispan/src/main/java/org/keycloak/models/sessions/infinispan/entities/SingleUseObjectValueEntity.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.keycloak.models.sessions.infinispan.entities;

import org.keycloak.models.SingleUseObjectValueModel;

import java.io.*;
import java.util.*;
import org.infinispan.commons.marshall.Externalizer;
import org.infinispan.commons.marshall.SerializeWith;

/**
 * @author hmlnarik
 */
@SerializeWith(SingleUseObjectValueEntity.ExternalizerImpl.class)
public class SingleUseObjectValueEntity implements SingleUseObjectValueModel {

    private final Map<String, String> notes;

    public SingleUseObjectValueEntity(Map<String, String> notes) {
        this.notes = notes == null ? Collections.EMPTY_MAP : new HashMap<>(notes);
    }

    @Override
    public Map<String, String> getNotes() {
        return Collections.unmodifiableMap(notes);
    }

    @Override
    public String getNote(String name) {
        return notes.get(name);
    }

    @Override
    public String toString() {
        return String.format("SingleUseObjectValueEntity [ notes=%s ]", notes.toString());
    }

    public static class ExternalizerImpl implements Externalizer<SingleUseObjectValueEntity> {

        private static final int VERSION_1 = 1;

        @Override
        public void writeObject(ObjectOutput output, SingleUseObjectValueEntity t) throws IOException {
            output.writeByte(VERSION_1);

            output.writeBoolean(t.notes.isEmpty());
            if (! t.notes.isEmpty()) {
                output.writeObject(t.notes);
            }
        }

        @Override
        public SingleUseObjectValueEntity readObject(ObjectInput input) throws IOException, ClassNotFoundException {
            byte version = input.readByte();
            
            if (version != VERSION_1) {
                throw new IOException("Invalid version: " + version);
            }
            boolean notesEmpty = input.readBoolean();

            Map<String, String> notes = notesEmpty ? Collections.EMPTY_MAP : (Map<String, String>) input.readObject();
            
            return new SingleUseObjectValueEntity(notes);
        }
    }
}

==> keycloak-26.1.1.tar.gz: keycloak-26.1.1/model/infinispan/src/main/java/org/keycloak/models/sessions/infinispan/entities/SingleUseObjectValueEntity.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.keycloak.models.sessions.infinispan.entities;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import org.infinispan.protostream.annotations.ProtoFactory;
import org.infinispan.protostream.annotations.ProtoField;
import org.infinispan.protostream.annotations.ProtoTypeId;
import org.keycloak.marshalling.Marshalling;
import org.keycloak.models.SingleUseObjectValueModel;

/**
 * @author hmlnarik
 */
@ProtoTypeId(Marshalling.SINGLE_USE_OBJECT_VALUE_ENTITY)
public class SingleUseObjectValueEntity implements SingleUseObjectValueModel {

    private final Map<String, String> notes;

    @ProtoFactory
    public SingleUseObjectValueEntity(Map<String, String> notes) {
        if (notes == null || notes.isEmpty()) {
            this.notes = Map.of();
            return;
        }
        var copy = new HashMap<>(notes);
        // protostream does not support null values for primitive types as string
        copy.values().removeIf(Objects::isNull);
        this.notes = Map.copyOf(copy);
    }

    @ProtoField(value = 1, mapImplementation = HashMap.class)
    @Override
    public Map<String, String> getNotes() {
        return notes;
    }

    @Override
    public String getNote(String name) {
        return notes.get(name);
    }

    @Override
    public String toString() {
        return String.format("SingleUseObjectValueEntity [ notes=%s ]", notes.toString());
    }

}
